#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ] 
then
  if [  -f ./LI72428.sh ]
 then
 echo "Ifix_LI72428: WVS Ifix LI72428 Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_LI72428.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI72428.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_LI72428: WVS Ifix LI72428 Installer command syntax: "
 echo " to install ifix  syntax: ifix_LI72428 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI72428.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   source /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_LI72428: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_LI72428: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/LI72428/ttsmcl.bak ] ; then
    echo "Ifix_LI72428: Ifix LI72428 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_LI72428: Checking for ifix files ..."
  if [ -f $thisDir/ttsmcl ] ; then
    if [ -f $thisDir/libssmlprocessor.so ] ; then
      echo "Ifix_LI72428: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/LI72428
      cp -p $thisDir/LI72428.sh $WVS_ROOT/ifix/ifix_LI72428.sh
      
      cp -p $WVS_ROOT/IBM/ibmtts/bin/ttsmcl $WVS_ROOT/ifix/LI72428/ttsmcl.bak
      cp -p $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.so $WVS_ROOT/ifix/LI72428/libssmlprocessor.so.bak
      cp -p $WVS_ROOT/IBM/ibmtts/lib/libjpnrom.so $WVS_ROOT/ifix/LI72428/libjpnrom.so.bak
      echo "Ifix_LI72428: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI72428: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI72428: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI72428
         exit -1
      fi      
      
      cp -fbp $thisDir/ttsmcl $WVS_ROOT/IBM/ibmtts/bin/.
      cp -fbp $thisDir/libssmlprocessor.so $WVS_ROOT/IBM/ibmtts/lib/.
      cp -fbp $thisDir/libjpnrom.so $WVS_ROOT/IBM/ibmtts/lib/.
      
      chmod 755 $WVS_ROOT/IBM/ibmtts/bin/ttsmcl
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.so	  
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libjpnrom.so	  

      echo "Ifix_LI72428: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI72428: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_LI72428: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_LI72428: Ifix is now applied, please reboot the system"
      
    else
      echo "Ifix_LI72428: Ifix files missing, please be sure this script is in same directory as the binary files" 
    fi
  fi
  cp -fp $thisDir/LI72428.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_LI72428: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/LI72428/ttsmcl.bak ] ; then
    if [ -f $WVS_ROOT/ifix/LI72428/libssmlprocessor.so.bak ] ; then
      echo "Ifix_LI72428: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_LI72428: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI72428: Application Server stopped successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI72428: Application Server reported failure during stopping. Ifix uninstallation will not continue"
         rm -rf $WVS_ROOT/ifix/LI72428
         exit -1
      fi
      
      cp -fp $WVS_ROOT/ifix/LI72428/ttsmcl.bak  $WVS_ROOT/IBM/ibmtts/bin/cwttsmcl
      cp -fp $WVS_ROOT/ifix/LI72428/libssmlprocessor.so.bak  $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.so
      cp -fp $WVS_ROOT/ifix/LI72428/libjpnrom.so.bak  $WVS_ROOT/IBM/ibmtts/lib/libvvgp.so
	  
      chmod 755 $WVS_ROOT/IBM/ibmtts/bin/ttsmcl
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.so	  
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libjpnrom.so	  
          
      echo "Ifix_LI72428: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI72428: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI72428: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       

      echo "Ifix_LI72428: Ifix is now uninstalled, please reboot the system"
      rm -rf $WVS_ROOT/ifix/LI72428
      echo "Ifix_LI72428:  Please remove the $WVS_ROOT/ifix/LI72428 directory before attempting a subsequent install of this ifix."
      
    else
      echo "Ifix_LI72428: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_LI72428: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
